---
id: tsdlsurface
title: TSDLSurface
sidebar_label: TSDLSurface
---

A collection of pixels used in software blitting.


## Methods

### `Method ConvertFormat:TSDLSurface(pixelFormat:UInt)`

Copies the surface to a new surface of the specified format.

This method is used to optimize images for faster repeat blitting. This is accomplished by converting the original
and storing the result as a new surface. The new, optimized surface can then be used as the source for future blits, making them faster.


#### Returns
The new surface, or Null on failure.


<br/>

### `Method Convert:TSDLSurface(format:TSDLPixelFormat)`

Copies an existing surface into a new one that is optimized for blitting to a surface of a specified pixel format.

#### Returns
The new surface that is created or NULL if it fails


<br/>

### `Method Format:TSDLPixelFormat()`

Returns the format of the pixels stored in the surface.

<br/>

### `Method Width:Int()`

Returns the width in pixels.

<br/>

### `Method Height:Int()`

Returns the height in pixels.

<br/>

### `Method Pitch:Int()`

Returns the length of a row of pixels in bytes.

<br/>

### `Method Pixels:Byte Ptr()`

Returns the pointer to the actual pixel data.

<br/>

### `Method GetClipRect(x:Int Var, y:Int Var, w:Int Var, h:Int Var)`

Gets the clipping rectangle for the surface.

When the surface is the destination of a blit, only the area within the clip rectangle is drawn into.


<br/>

### `Method SetClipRect(x:Int, y:Int, w:Int, h:Int)`

Sets the clipping rectangle for a surface.

When the surface is the destination of a blit, only the area within the clip rectangle is drawn into.
Note that blits are automatically clipped to the edges of the source and destination surfaces.


#### Returns
True if the rectangle intersects the surface, otherwise False and blits will be completely clipped.


<br/>

### `Method GetColorKey:Int(key:UInt Var)`

Gets the color key (transparent pixel) for a surface.

The color key is a pixel of the format used by the surface, as generated by SDLMapRGB.
If the surface doesn't have color key enabled this method returns -1.


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method GetAlphaMod:Int(alpha:Byte Var)`

Gets the additional alpha value used in blit operations.

#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method GetBlendMode:Int(blendMode:Int Var)`

Gets the blend mode used for blit operations.

<b>blendMode</b> will be filled in with one of the following : [SDL_BLENDMODE_NONE](../../../sdl/sdl.sdlsurface/#const-sdlblendmodenoneint-00000000), [SDL_BLENDMODE_BLEND](../../../sdl/sdl.sdlsurface/#const-sdlblendmodeblendint-00000001), [SDL_BLENDMODE_ADD](../../../sdl/sdl.sdlsurface/#const-sdlblendmodeaddint-00000002) or [SDL_BLENDMODE_MOD](../../../sdl/sdl.sdlsurface/#const-sdlblendmodemodint-00000004).


#### Returns
0 on success or a negative error code on failure


<br/>

### `Method GetColorMod:Int(r:Byte Var, g:Byte Var, b:Byte Var)`

Gets the additional color value multiplied into blit operations.

#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method Lock:Int()`

Sets up a surface for directly accessing the pixels.

Between calls to [Lock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-lockint)() / [Unlock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-unlockint)(), you can write to and read from surface->pixels, using the pixel format stored
in surface->format. Once you are done accessing the surface, you should use [Unlock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-unlockint)() to release it.
Not all surfaces require locking. If [MustLock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-mustlockint)() evaluates to 0, then you can read and write to the surface at any time,
and the pixel format of the surface will not change.


#### Returns
0 on success or a negative error code on failure


<br/>

### `Method Unlock:Int()`

Releases a surface after directly accessing the pixels.

Between calls to [Lock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-lockint)() / [Unlock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-unlockint)(), you can write to and read from surface->pixels, using the pixel format stored
in surface->format. Once you are done accessing the surface, you should use [Unlock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-unlockint)() to release it.
Not all surfaces require locking. If [MustLock](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-mustlockint)() evaluates to 0, then you can read and write to the surface at any time,
and the pixel format of the surface will not change.


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method MustLock:Int()`

Determines whether a surface must be locked for access.

#### Returns
True if the surface must be locked for access, False if not.


<br/>

### `Method SetColorKey:Int(flag:Int, key:UInt)`

Sets the color key (transparent pixel) in a surface.

The color key defines a pixel value that will be treated as transparent in a blit. It is a pixel of the format used by
the surface, as generated by SDLMapRGB().
RLE acceleration can substantially speed up blitting of images with large horizontal runs of transparent pixels. See [SetRLE](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setrleintflagint)() for details.


#### Returns
0 on success or a negative error code on failure/


<br/>

### `Method SetAlphaMod:Int(alpha:Byte)`

Sets an additional alpha value used in blit operations.

When this surface is blitted, during the blit operation the source alpha value is modulated by this alpha
value according to the following formula: srcA = srcA * (alpha / 255)


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method SetBlendMode:Int(blendMode:Int)`

Sets the blend mode used for blit operations.

<b>blendMode</b> may be one of the following: [SDL_BLENDMODE_NONE](../../../sdl/sdl.sdlsurface/#const-sdlblendmodenoneint-00000000), [SDL_BLENDMODE_BLEND](../../../sdl/sdl.sdlsurface/#const-sdlblendmodeblendint-00000001), [SDL_BLENDMODE_ADD](../../../sdl/sdl.sdlsurface/#const-sdlblendmodeaddint-00000002) or [SDL_BLENDMODE_MOD](../../../sdl/sdl.sdlsurface/#const-sdlblendmodemodint-00000004).
To copy a surface to another surface (or texture) without blending with the existing data, the blendmode of the
SOURCE surface should be set to [SDL_BLENDMODE_NONE](../../../sdl/sdl.sdlsurface/#const-sdlblendmodenoneint-00000000).


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method SetColorMod:Int(r:Byte, g:Byte, b:Byte)`

Sets an additional color value multiplied into blit operations.

When this surface is blitted, during the blit operation each source color channel is modulated by the
appropriate color value according to the following formula: srcC = srcC * (color / 255)


<br/>

### `Method SetRLE:Int(flag:Int)`

Sets the RLE acceleration hint for a surface.

<br/>

### `Method FillRect:Int(x:Int, y:Int, w:Int, h:Int, color:UInt)`

Perform a fast fill of a rectangle with a specific color.

<b>color</b> should be a pixel of the format used by the surface, and can be generated by SDLMapRGB() or SDLMapRGBA().
If the color value contains an alpha component then the destination is simply filled with that alpha information, no blending takes place.
If there is a clip rectangle set on the destination (set via SDL_SetClipRect()), then this function will fill based on the intersection of the clip rectangle and rect.


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method FillRects:Int(rects:Int Ptr, count:Int, color:UInt)`

Performs a fast fill of a set of rectangles with a specific color.

<b>rects</b> consists of <b>count</b> sets of x,y,w,h Ints packed together.
<b>color</b> should be a pixel of the format used by the surface, and can be generated by SDLMapRGB or SDLMapRGBA().
If the color value contains an alpha component then the destination is simply filled with that alpha information, no blending takes place.
If there is a clip rectangle set on the destination (set via [SetClipRect](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setcliprectxint-yint-wint-hint)()), then this method will fill based on the
intersection of the clip rectangle and rects.


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method BlitScaled:Int(sx:Int, sy:Int, sw:Int, sh:Int, dest:TSDLSurface, dx:Int = 0, dy:Int = 0)`

Performs a scaled surface copy to a destination surface.

Use all zero source coords to copy the entire surface.
Use all zero destination coords to copy into the entire surface.


#### Returns
0 on success or a negative error code on failure.


<br/>

### `Method Free()`

Frees the surface.

<br/>

## Functions

### `Function CreateRGB:TSDLSurface(width:Int, height:Int, depth:Int, Rmask:UInt, Gmask:UInt, Bmask:UInt, Amask:UInt)`

Allocates a new RGB surface.

If depth is 4 or 8 bits, an empty palette is allocated for the surface.
If depth is greater than 8 bits, the pixel format is set using the [RGBA]mask parameters.
The [RGBA]mask parameters are the bitmasks used to extract that color from a pixel. For instance,
Rmask being FF000000 means the red data is stored in the most significant byte. Using zeros for the RGB masks sets a default value,
based on the depth. (e.g. [CreateRGB](../../../sdl/sdl.sdlsurface/tsdlsurface/#function-creatergbtsdlsurfacewidthint-heightint-depthint-rmaskuint-gmaskuint-bmaskuint-amaskuint)(0,w,h,32,0,0,0,0);) However, using zero for the Amask results in an Amask of 0.
By default surfaces with an alpha mask are set up for blending as with [SetBlendMode](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setblendmodeintblendmodeint)(#SDL_BLENDMODE_BLEND)
You can change this by calling [SetBlendMode](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setblendmodeintblendmodeint)() and selecting a different blendMode.


#### Returns
The new surface that is created or Null if it fails.


<br/>

### `Function CreateRGBWithFormat:TSDLSurface(width:Int, height:Int, depth:Int, format:UInt)`

Allocates an RGB surface.

If the method runs out of memory, it will return Null.


#### Returns
A new surface on success or Null on failure.


<br/>

### `Function CreateRGBFrom:TSDLSurface(pixels:Byte Ptr, width:Int, height:Int, depth:Int, pitch:Int, Rmask:UInt, Gmask:UInt, Bmask:UInt, Amask:UInt)`

Allocates a new RGB surface with existing pixel data.

If depth is 4 or 8 bits, an empty palette is allocated for the surface.
If depth is greater than 8 bits, the pixel format is set using the [RGBA]mask parameters.
The [RGBA]mask parameters are the bitmasks used to extract that color from a pixel. For instance,
Rmask being FF000000 means the red data is stored in the most significant byte. Using zeros for the RGB masks sets a default value,
based on the depth. (e.g. [CreateRGB](../../../sdl/sdl.sdlsurface/tsdlsurface/#function-creatergbtsdlsurfacewidthint-heightint-depthint-rmaskuint-gmaskuint-bmaskuint-amaskuint)(0,w,h,32,0,0,0,0);) However, using zero for the Amask results in an Amask of 0.
By default surfaces with an alpha mask are set up for blending as with [SetBlendMode](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setblendmodeintblendmodeint)(#SDL_BLENDMODE_BLEND)
You can change this by calling [SetBlendMode](../../../sdl/sdl.sdlsurface/tsdlsurface/#method-setblendmodeintblendmodeint)() and selecting a different blendMode.
Note: No copy is made of the pixel data. Pixel data is not managed automatically; you must free the surface before you free the pixel data.


#### Returns
The new surface that is created or Null if it fails.


<br/>

### `Function LoadBMP:TSDLSurface(file:String)`

Loads a surface from a BMP file.

<br/>

